# HAWCsat Simulator Package

[![Documentation Status](https://readthedocs.org/projects/hawc-simulator/badge/?version=latest)](https://usask_arg_example.readthedocs.io/en/latest/?badge=latest)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/usask-arg/hawc-simulator/main.svg)](https://results.pre-commit.ci/latest/github/usask-arg/usask_arg_example/main)

## Installation
The package can be installed through

`pip install hawcsimulator`

## Usage
Documentation can be found at  https://hawc-simulator.readthedocs.io/

## License
This project is licensed under the MIT license
